InvalidIntervalError

Enum InvalidIntervalError 

pub enum InvalidIntervalError {
    StartAfterEnd,
}
Error returned when constructing an Interval with invalid bounds.

Variants



StartAfterEnd

The start instant is after the end instant (!(start <= end)).

This also triggers for NaN endpoints, since NaN comparisons always return false.