Module period

Module period 

Generic periods and interval-list operations.

Interval is a half-open range [start, end) over any totally-ordered instant type. It is parameterised on T: Copy + PartialOrd so that the same type works for Time<A> on any axis as well as for chrono::DateTime<Utc>.

Re-exports

pub use series::TimeSeries;
pub use series::TimeSeriesError;

Modules

series
TimeSeries — exact-step iterator over Time<S>.

Structs

Interval
Half-open time interval [start, end).

Enums

InvalidIntervalError
Error constructing an super::Interval with invalid bounds.
PeriodListError
Invariants on a period list.

Functions

complement_within
Gaps inside outer that are not covered by any interval in periods.

Type Aliases

Period
Typed time period on a given scale.