pub trait TimeFormat:
Sealed
+ Copy
+ Clone
+ Debug
+ 'static {
type Unit: Unit;
const NAME: &'static str;
}Expand description
Marker trait for an external time encoding such as JD or Unix time.
A TimeFormat value is a zero-sized tag that identifies how a time instant
is expressed (Julian Day, Modified Julian Day, J2000 seconds, POSIX seconds,
GPS seconds). It is orthogonal to Scale, which identifies the physical
time axis.
Sealed: implementations live in this crate only.
Required Associated Constants
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.