EncodedTime

Struct EncodedTime 

pub struct EncodedTime<S: Scale, R: TimeRepresentation> { /* private fields */ }
A typed external representation of a Time<S> instant.

Implementations

Source

impl<S: Scale, R: TimeRepresentation> EncodedTime<S, R>

pub const fn raw(self) -> Quantity<R::Unit>

Return the underlying typed quantity.

pub const fn quantity(self) -> Quantity<R::Unit>

Alias for Self::raw.

Source

impl<S: Scale, R> EncodedTime<S, R>

pub fn try_new(raw: Quantity<R::Unit>) -> Result<Self, ConversionError>

Construct a typed encoded instant from its raw quantity.

pub fn try_to_time(self) -> Result<Time<S>, ConversionError>

Convert this encoded instant to the canonical Time<S> model.

Snapshots the active time-data bundle at call time via TimeContext::new. For reproducible pipelines, prefer to_time_with with an explicit context.

pub fn to_time_with(self, ctx: &TimeContext) -> Result<Time<S>, ConversionError>

Convert this encoded instant to the canonical Time<S> model using an explicit context.

Source

impl<S: Scale, R> EncodedTime<S, R>

pub fn to_time(self) -> Time<S>

Infallible conversion to the canonical Time<S> model.

pub fn to<T>(self) -> T::Output

Unified infallible conversion to a target scale or encoded format.

pub fn try_to<T>(self) -> Result<T::Output, ConversionError>
where T: ConversionTarget<S>,

Unified fallible conversion to a target scale or encoded format.

Source

impl<S: Scale, R> EncodedTime<S, R>

pub fn to_with<T>(self, ctx: &TimeContext) -> Result<T::Output, ConversionError>

Unified context-backed conversion to a target scale or encoded format.