pub struct EncodedTime<S: Scale, R: TimeRepresentation> { /* private fields */ }Expand description
A typed external representation of a Time<S> instant.
Implementations
Sourceimpl<S: Scale, R: TimeRepresentation> EncodedTime<S, R>
impl<S: Scale, R: TimeRepresentation> EncodedTime<S, R>
Sourceimpl<S: Scale, R> EncodedTime<S, R>where
R: RepresentationForScale<S>,
impl<S: Scale, R> EncodedTime<S, R>where
R: RepresentationForScale<S>,
Sourcepub fn try_new(raw: Quantity<R::Unit>) -> Result<Self, ConversionError>
pub fn try_new(raw: Quantity<R::Unit>) -> Result<Self, ConversionError>
Construct a typed encoded instant from its raw quantity.
Sourcepub fn try_to_time(self) -> Result<Time<S>, ConversionError>
pub fn try_to_time(self) -> Result<Time<S>, ConversionError>
Convert this encoded instant to the canonical Time<S> model.
Snapshots the active time-data bundle at call time via
TimeContext::new. For reproducible pipelines, prefer
to_time_with with an explicit context.
Sourcepub fn to_time_with(self, ctx: &TimeContext) -> Result<Time<S>, ConversionError>
pub fn to_time_with(self, ctx: &TimeContext) -> Result<Time<S>, ConversionError>
Convert this encoded instant to the canonical Time<S> model using an explicit context.
Sourceimpl<S: Scale, R> EncodedTime<S, R>where
R: InfallibleRepresentationForScale<S>,
impl<S: Scale, R> EncodedTime<S, R>where
R: InfallibleRepresentationForScale<S>,
Sourcepub fn to<T>(self) -> T::Outputwhere
T: InfallibleConversionTarget<S>,
pub fn to<T>(self) -> T::Outputwhere
T: InfallibleConversionTarget<S>,
Unified infallible conversion to a target scale or encoded format.
Sourcepub fn try_to<T>(self) -> Result<T::Output, ConversionError>where
T: ConversionTarget<S>,
pub fn try_to<T>(self) -> Result<T::Output, ConversionError>where
T: ConversionTarget<S>,
Unified fallible conversion to a target scale or encoded format.
Sourceimpl<S: Scale, R> EncodedTime<S, R>where
R: RepresentationForScale<S>,
impl<S: Scale, R> EncodedTime<S, R>where
R: RepresentationForScale<S>,
Sourcepub fn to_with<T>(self, ctx: &TimeContext) -> Result<T::Output, ConversionError>where
T: ContextConversionTarget<S>,
pub fn to_with<T>(self, ctx: &TimeContext) -> Result<T::Output, ConversionError>where
T: ContextConversionTarget<S>,
Unified context-backed conversion to a target scale or encoded format.